@@ -142,6 +142,12 @@ def _get_options(argv):
         action="append",
         help="additional rule parameters (in a yaml file)")
 
+    parser.add_argument(
+        "--data-file",
+        dest="data_file",
+        default=None,
+        help="arbitrary data file made available to job")
+
     parser.add_argument(
         "--example_rules",
         dest="example_rules",
@@ -165,7 +171,15 @@ def _get_options(argv):
             result.update(yaml.load(open(options.parameter_file, "r")))
         except Exception as e:
             message = "Error opening parameter file: %s %s"
-            log.error(message % (options.parameter_file, e))
+            log.error(message, options.parameter_file, e)
+
+    if options.data_file:
+        try:
+            data_file = open(options.data_file).readlines()
+            result['data_file'] = data_file
+        except Exception as e:
+            message = "Could not open/process data file: %s %s"
+            log.error(message, options.data_file, e)
 
     return result
 
