@@ -31,9 +31,11 @@ def unpickle_connection(pickled_connection):
     (func, args) = pickle.loads(pickled_connection)
     return func(*args)
 
-
 def run_rule_async(rule_name, automatic_cycle, settings, reply_to):
     setproctitle("inferno - %s" % rule_name)
+    signal.signal(signal.SIGHUP, signal.SIG_IGN)
+    signal.signal(signal.SIGINT, signal.SIG_IGN)
+    signal.signal(signal.SIGTERM, signal.SIG_IGN)
     pipe = unpickle_connection(reply_to)
     response_sent = False
     pid_created = False
@@ -60,7 +62,7 @@ def run_rule_async(rule_name, automatic_cycle, settings, reply_to):
                 response_sent = True
                 job.wait()
             else:
-                pipe.send({'error': "job didn't start"})
+                pipe.send({'info': "not enough blobs"})
                 pipe.close()
                 response_sent = True
         else:
@@ -113,7 +115,8 @@ class InfernoDaemon(object):
                 if rule.name == rule_name:
                     return rule
 
-    def run_rule(self, rule, automatic_cycle=False, params=None):
+    def run_rule(self, rule, automatic_cycle=False,
+                 params=None, wait_for_id=False):
         try:
             job_settings = self.settings.copy()
             if params:
@@ -123,14 +126,15 @@ class InfernoDaemon(object):
             name = rule.qualified_name
             args = (name, automatic_cycle, job_settings, reply_to)
             Process(target=run_rule_async, args=args).start()
-            msg = parent.recv()
-            if msg and 'job' in msg:
-                job = msg['job']
-                self.history[job['job_name']] = job
-                return msg['job']
-            elif 'error' in msg:
-                log.error('Error creating job: %s' % msg)
-                return None
+            if wait_for_id:
+                msg = parent.recv()
+                if msg and 'job' in msg:
+                    job = msg['job']
+                    self.history[job['job_name']] = job
+                    return msg['job']
+                elif 'error' in msg:
+                    log.error('Error creating job: %s' % msg)
+                    return None
         except Exception as e:
             log.error("Error running rule: %s" % e)
             raise e
@@ -138,6 +142,7 @@ class InfernoDaemon(object):
     def die(self, x=None, y=None):
         print 'dying...'
         try:
+            self.disco_ball.stopped = True
             self.disco_ball.server.terminate()
         except:
             pass
@@ -158,6 +163,8 @@ class InfernoDaemon(object):
 
             # cycle through all the automatic rules
             for rule in auto_rules:
+                # sleep for a bit between rules
+                time.sleep(self.settings['spawn_delay'])
 
                 if self.stopped:
                     break
@@ -168,7 +175,4 @@ class InfernoDaemon(object):
 
                 self.run_rule(rule, automatic_cycle=True)
 
-                # sleep for a bit between rules
-                time.sleep(self.settings['spawn_delay'])
-
         self.die()
