@@ -69,7 +69,7 @@ class InfernoRule(object):
                  # map
                  map_init_function=lambda x, y: x,
                  map_function=keyset_map,
-                 map_input_stream=chunk_csv_stream,
+                 map_input_stream=chunk_csv_keyset_stream,
                  map_output_stream=(
                      map_output_stream, disco_output_stream),
 
@@ -224,4 +224,5 @@ class InfernoRule(object):
             reduce_function=fstr(self.reduce_function),
             keysets=self.params.keysets,
             parts_preprocess=self.params.parts_preprocess,
-            parts_postprocess=self.params.parts_postprocess)
+            parts_postprocess=self.params.parts_postprocess
+        )
